==> jc-1.4.0.tar.gz: java/nio/charset/CoderResult__241.h <==
// final class java.nio.charset.CoderResult$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ec857df8af6bd34 java_nio_charset_CoderResult__241
// @dep_class 14254178dbad6381 java_nio_charset_CoderResult__24Cache

// header file dependencies
// @dep_header java_nio_charset_CoderResult__24Cache

#include "java/nio/charset/CoderResult__24Cache.h"

#ifndef _JC_java_nio_charset_CoderResult__241_H_
#define _JC_java_nio_charset_CoderResult__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_charset_CoderResult$object;

// Typedefs
typedef struct _jc_java_nio_charset_CoderResult__241$sub_refs	_jc_java_nio_charset_CoderResult__241$sub_refs;
typedef struct _jc_java_nio_charset_CoderResult__241$sub_nonrefs	_jc_java_nio_charset_CoderResult__241$sub_nonrefs;
typedef struct _jc_java_nio_charset_CoderResult__241$refs	_jc_java_nio_charset_CoderResult__241$refs;
typedef struct _jc_java_nio_charset_CoderResult__241$nonrefs	_jc_java_nio_charset_CoderResult__241$nonrefs;
typedef struct _jc_java_nio_charset_CoderResult__241$object	_jc_java_nio_charset_CoderResult__241$object;

typedef const struct _jc_java_nio_charset_CoderResult__241$vmethods	_jc_java_nio_charset_CoderResult__241$vmethods;
typedef const struct _jc_java_nio_charset_CoderResult__241$vtable	_jc_java_nio_charset_CoderResult__241$vtable;
typedef const struct _jc_java_nio_charset_CoderResult__241$vtype	_jc_java_nio_charset_CoderResult__241$vtype;

// Constructors
extern void _jc_java_nio_charset_CoderResult__241$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_charset_CoderResult__241$object *);

// Virtual methods
extern struct _jc_java_nio_charset_CoderResult$object *_jc_java_nio_charset_CoderResult__241$method$make$f3cbfffb1f7afd3c(_jc_env *, struct _jc_java_nio_charset_CoderResult__241$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_java_nio_charset_CoderResult__241$method_info$make$f3cbfffb1f7afd3c;

// Virtual methods structure
struct _jc_java_nio_charset_CoderResult__241$vmethods {
	struct _jc_java_nio_charset_CoderResult$object	*(*make$f3cbfffb1f7afd3c)(_jc_env *, struct _jc_java_nio_charset_CoderResult__241$object *, jint);
};

// Vtable
struct _jc_java_nio_charset_CoderResult__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_CoderResult__24Cache$vmethods	java_nio_charset_CoderResult__24Cache;
	_jc_java_nio_charset_CoderResult__241$vmethods	java_nio_charset_CoderResult__241;
};

// Vtype
struct _jc_java_nio_charset_CoderResult__241$vtype {
	_jc_type			type;
	_jc_java_nio_charset_CoderResult__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_CoderResult__241$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_charset_CoderResult__241$refs {
    _jc_java_nio_charset_CoderResult__241$sub_refs	java_nio_charset_CoderResult__241;
    _jc_java_nio_charset_CoderResult__24Cache$sub_refs	java_nio_charset_CoderResult__24Cache;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_CoderResult__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_CoderResult__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_CoderResult__24Cache$sub_nonrefs	java_nio_charset_CoderResult__24Cache;
    _jc_java_nio_charset_CoderResult__241$sub_nonrefs	java_nio_charset_CoderResult__241;
};

// Object instance structure
struct _jc_java_nio_charset_CoderResult__241$object {
	_jc_java_nio_charset_CoderResult__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_CoderResult__241$vtype	*vtype;
	_jc_java_nio_charset_CoderResult__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_CoderResult__241$vtype _jc_java_nio_charset_CoderResult__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_CoderResult__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_CoderResult__241$class_object;

#endif	/* _JC_java_nio_charset_CoderResult__241_H_ */

==> jc-1.4.6.tar.gz: java/nio/charset/CoderResult__241.h <==
// final class java.nio.charset.CoderResult$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ec857df8af6bd34 java_nio_charset_CoderResult__241
// @dep_class 14254178dbad6381 java_nio_charset_CoderResult__24Cache

// header file dependencies
// @dep_header java_nio_charset_CoderResult__24Cache

#include "java/nio/charset/CoderResult__24Cache.h"

#ifndef _JC_java_nio_charset_CoderResult__241_H_
#define _JC_java_nio_charset_CoderResult__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_charset_CoderResult$object;

// Typedefs
typedef struct _jc_java_nio_charset_CoderResult__241$sub_refs	_jc_java_nio_charset_CoderResult__241$sub_refs;
typedef struct _jc_java_nio_charset_CoderResult__241$sub_nonrefs	_jc_java_nio_charset_CoderResult__241$sub_nonrefs;
typedef struct _jc_java_nio_charset_CoderResult__241$refs	_jc_java_nio_charset_CoderResult__241$refs;
typedef struct _jc_java_nio_charset_CoderResult__241$nonrefs	_jc_java_nio_charset_CoderResult__241$nonrefs;
typedef struct _jc_java_nio_charset_CoderResult__241$object	_jc_java_nio_charset_CoderResult__241$object;

typedef const struct _jc_java_nio_charset_CoderResult__241$vmethods	_jc_java_nio_charset_CoderResult__241$vmethods;
typedef const struct _jc_java_nio_charset_CoderResult__241$vtable	_jc_java_nio_charset_CoderResult__241$vtable;
typedef const struct _jc_java_nio_charset_CoderResult__241$vtype	_jc_java_nio_charset_CoderResult__241$vtype;

// Constructors
extern void _jc_java_nio_charset_CoderResult__241$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_charset_CoderResult__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_nio_charset_CoderResult$object *_jc_java_nio_charset_CoderResult__241$method$make$f3cbfffb1f7afd3c(_jc_env *, struct _jc_java_nio_charset_CoderResult__241$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_charset_CoderResult__241$method_info$make$f3cbfffb1f7afd3c;

// Virtual methods structure
struct _jc_java_nio_charset_CoderResult__241$vmethods {
	struct _jc_java_nio_charset_CoderResult$object	*(*make$f3cbfffb1f7afd3c)(_jc_env *, struct _jc_java_nio_charset_CoderResult__241$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_charset_CoderResult__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_CoderResult__24Cache$vmethods	java_nio_charset_CoderResult__24Cache;
	_jc_java_nio_charset_CoderResult__241$vmethods	java_nio_charset_CoderResult__241;
};

// Vtype
struct _jc_java_nio_charset_CoderResult__241$vtype {
	_jc_type			type;
	_jc_java_nio_charset_CoderResult__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_CoderResult__241$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_charset_CoderResult__241$refs {
    _jc_java_nio_charset_CoderResult__241$sub_refs	java_nio_charset_CoderResult__241;
    _jc_java_nio_charset_CoderResult__24Cache$sub_refs	java_nio_charset_CoderResult__24Cache;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_CoderResult__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_CoderResult__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_CoderResult__24Cache$sub_nonrefs	java_nio_charset_CoderResult__24Cache;
    _jc_java_nio_charset_CoderResult__241$sub_nonrefs	java_nio_charset_CoderResult__241;
};

// Object instance structure
struct _jc_java_nio_charset_CoderResult__241$object {
	_jc_java_nio_charset_CoderResult__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_CoderResult__241$vtype	*vtype;
	_jc_java_nio_charset_CoderResult__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_CoderResult__241$vtype _jc_java_nio_charset_CoderResult__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_CoderResult__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_CoderResult__241$class_object;

#endif	/* _JC_java_nio_charset_CoderResult__241_H_ */
